# dwbzen
dwbzen has python implementations of some of the classes in my github projects:

* [commonlib](https://github.com/dwbzen/commonlib) : math classes including Markov Chains,
and utilities/classes used by other projects.

* [text-processing](https://github.com/dwbzen/text-processing) : Generates text using Markov chains, 
and part-of-speech (POS) patterns from POS word files Part Of Speech Database 

* [music_framework](https://github.com/dwbzen/music-framework) : A Java framework encapsulating musical structure, 
notation and theory for purposes of composition and analysis. 

dwbzen includes the following sub-packages:
## common

## text

## music


I used [Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write content.